StreamStatistics class
Statistics about the streaming, bitrate, errors, drops etc.
rttMicros 与 bytesSend 依赖 RootEncoder 2.7.0+ RTMP 客户端(需开启 setRtmpShouldSendPings 后 RTT 才有效)。
Constructors
- StreamStatistics({required int? cacheSize, required int? sentAudioFrames, required int? sentVideoFrames, required int? droppedAudioFrames, required int? droppedVideoFrames, required int? bitrate, required int? width, required int? height, required bool? isAudioMuted, int? fps, int? rttMicros, int? bytesSend})
Properties
- bitrate → int?
-
final
- bytesSend → int?
-
final
- cacheSize → int?
-
final
- droppedAudioFrames → int?
-
final
- droppedVideoFrames → int?
-
final
- fps → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
final
- isAudioMuted → bool?
-
final
- rttMicros → int?
-
RTMP 往返时延(微秒),需
setRtmpShouldSendPings(true)且推流建立后由服务端响应 ping。final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentAudioFrames → int?
-
final
- sentVideoFrames → int?
-
final
- width → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited