rtmp_streaming library
Classes
- CameraController
- Controls a device camera.
- CameraDescription
- CameraPreview
- CameraValue
- The state of a CameraController.
- StreamDestination
- One destination for CameraController.startMultiStreaming.
- StreamStatistics
- Statistics about the streaming, bitrate, errors, drops etc.
Enums
- CameraLensDirection
- OverlayPosition
- Overlay corner / center for CameraController.setOverlayText / CameraController.setOverlayImage.
- ResolutionPreset
- Affect the quality of video recording and image capture.
- StreamingProtocol
- Streaming protocol for CameraController.startVideoStreaming.
Functions
-
availableCameras(
) → Future< List< CameraDescription> > - Completes with a list of available cameras.
-
isMultiStreamingProtocolSupported(
StreamingProtocol protocol) → bool - Protocols allowed in CameraController.startMultiStreaming (excludes WHIP/WHEP).
-
isStreamingProtocolSupported(
StreamingProtocol protocol) → bool -
serializeOverlayPosition(
OverlayPosition position) → String -
serializeResolutionPreset(
ResolutionPreset resolutionPreset) → String - Returns the resolution preset as a String.
-
serializeStreamingProtocol(
StreamingProtocol protocol) → String
Exceptions / Errors
- CameraException
- This is thrown when the plugin reports an error.